@@ -3,12 +3,12 @@ from dataclasses import dataclass, field
 
 import pytest as pytest
 from dependency_injector import containers, providers
+from faker import Faker
 from sqlalchemy import Column, String, create_engine, orm
 from sqlalchemy.orm import Session, mapper
 from sqlalchemy.pool import NullPool
 
 from idp_authentication.config import Config, get_test_memory_db_uri
-from idp_authentication.users.tests.mock_event_producer import MockEventProducer
 from idp_authentication.users.base_classes.singleton import Singleton
 from idp_authentication.users.di.containers import UsersModuleDIContainer
 from idp_authentication.users.domain.entities import AppEntity, User, UserRole
@@ -19,6 +19,9 @@ from idp_authentication.users.infrastructure.database.sqlalchemy.base import (
 from idp_authentication.users.infrastructure.database.sqlalchemy.custom_orm_column_types import (
     UUID,
 )
+from idp_authentication.users.tests.mock_event_producer import MockEventProducer
+
+fake = Faker()
 
 TEST_ROLE_1 = "TestRole_1"
 TEST_ROLE_2 = "TestRole_2"
@@ -205,6 +208,40 @@ def user_without_role(container):
     return session.query(User).filter(User.username == "test3").first()
 
 
+@pytest.fixture(scope="function")
+def make_user(container):
+    def create_user(**overrides):
+        default_data = {
+            "username": fake.user_name(),
+            "email": fake.email(),
+            "first_name": fake.first_name(),
+            "last_name": fake.last_name(),
+            "is_active": True,
+            "is_superuser": False,
+            "is_staff": False,
+            "user_roles": [
+                UserRole(
+                    role=TEST_ROLE_1,
+                    app_entities_restrictions={VEHICLE_APP_ENTITY_IDENTIFIER: [1, 2]},
+                    permission_restrictions={
+                        TEST_PERMISSION: {VEHICLE_APP_ENTITY_IDENTIFIER: [1]}
+                    },
+                )
+            ],
+        }
+        default_data.update(overrides)
+
+        user = User(**default_data)
+
+        session = container.database.provided().session
+        session.add(user)
+        session.commit()
+
+        return user
+
+    return create_user
+
+
 @pytest.fixture(scope="function")
 def vehicle(container):
     session = container.database().session
