@@ -6,7 +6,10 @@ from idp_authentication.users.base_classes.base_use_case import BaseUseCase
 
 class GetUsersWithAccessToAppEntityRecordUseCase(BaseUseCase):
     def execute(
-        self, app_entity_type: str, record_identifier: Any, roles: list[ChoiceEnum]
+        self,
+        app_entity_type: str,
+        record_identifier: Any,
+        roles: list[ChoiceEnum | str],
     ):
         self._verify_app_entity_type(app_entity_type)
         for role in roles:
