@@ -1,6 +1,5 @@
 from collections import defaultdict
 from copy import deepcopy
-from typing import List
 
 from idp_authentication.custom_types import UserRecordDict
 from idp_authentication.enums import ChoiceEnum
@@ -44,7 +43,7 @@ class ProcessUserMessageUseCase(UseCasePort):
         users_unit_of_work: UsersUnitOfWorkPort,
         roles: ChoiceEnum,
         create_or_update_user_use_case: UseCasePort,
-        tenants: List[str],
+        tenants: list[str],
         app_identifier: str,
     ):
         self.users_unit_of_work = users_unit_of_work
@@ -72,8 +71,7 @@ class ProcessUserMessageUseCase(UseCasePort):
         if self.app_identifier in app_specific_configs:
             self._process_user_data_with_access_to_app(data)
         else:
-            # TODO: To Implement
-            pass
+            self._verify_if_user_exists_and_delete_roles(username=data.get("username"))
 
     def _process_user_data_with_access_to_app(self, data: UserRecordDict):
         reported_user_app_configs = data.get("app_specific_configs", {}).get(
@@ -142,3 +140,20 @@ class ProcessUserMessageUseCase(UseCasePort):
                     uow.user_repository.remove_user_role(user, user_role)
 
             uow.commit()
+
+    def _verify_if_user_exists_and_delete_roles(self, username: str):
+        """
+        Having arrived here means that the user does not have access in the current app
+        Verify however if the user already exists in the database of any tenant
+        If this is the case, delete his/her roles.
+        """
+        for tenant in self.tenants:
+            with self.users_unit_of_work as uow:
+                if user := uow.user_repository.get_or_none(username=username):
+                    print(f"Deleting roles for user {username} in tenant {tenant}")
+
+                    for user_role in user.user_roles:
+                        uow.user_role_repository.delete(user_role)
+                        uow.user_repository.remove_user_role(user, user_role)
+
+                    uow.commit()
